# draw_fig2.R
#
# Jari Vauhkonen
# 4 July 2018
#
# This R-script can be used to visualize results as in Figure 2 of the comment paper;
#
# Note: for ease, I assume that previous analysis scripts were run earlier and the resulting R-objects were stored to files which are loaded below.
# The code below can be executed this way, or running the earlier scripts subsequently and commenting off the statements cleaning the workspace and loading earlier objects
#

rm(list=ls())
setwd("C:/temp")

tiff("Fig2.tif", width=190, height=275, units="mm", res=300, pointsize=10)
par(mfcol=c(3,2), mar=c(5,4,1,1))

# Figure 2(a-c) from the first template database
load("nini_100.RData")

# Species index pointing to the following vector of dominant species : "aw" "pl" "sb" "sw"
# For visualizing, I use of constant value of 1 producing the results for AW
sp <- 1

# Loop over the three column indices used to store the attributes height, basal area, and volume (first index is the dominant species)
for (nro in 2:4) {
  # Extract the curves from the data structures; cf. earlier scripts
  closest.curve.index <- as.numeric(inds.sp.t1[sp,nro])
  if (nro < 3) {
    avg.curve.index <- si.sps[sp]
  } else {
    avg.curve.index <- nini.sps[sp]
  }
  candidate.curves <- list( h=sp.h.curves[sp], g=sp.g.curves[sp], v=sp.v.curves[sp] )
  current.means.t1 <- list( a=a[sp], h=h.t1[sp], g=g.t1[sp], v=v.t1[sp] )
  curves <- candidate.curves[nro-1][[1]][1][[1]]

  # Plotting conventions
  maxs <- c(0,40,37,550)
  plot(range(stand.age), c(0,maxs[nro]), type="n", xlab="Age, years", ylab="", cex.lab=1.25, cex.axis=1.25)
  if (nro==2) {
    text(5, 39.75, "(a)", cex=1.5)
    mtext("Height, m", 2, 2.5, cex=0.85)
  } else if (nro==3) {
    text(5, 36.75, "(b)", cex=1.5)
    mtext(expression(paste("Basal area,  ", m^2/ha)), 2, 2.5, cex=0.85)
  } else {
    text(5, 546, "(c)", cex=1.5)
    mtext(expression(paste("Volume,  ", m^3/ha)), 2, 2.5, cex=0.85)
  } 

  # Draw the curve templates
  for (cc in 1:dim(curves)[1]){
    c <- curves[cc,]
    lines(c, col="grey", lwd=0.5)
  }

  # Draw the observation as a point and draw a vertical line from it to the closest template, illustrating the discrepancy from the observed current state to the point from which the growht projection starts
  points(current.means.t1$a, current.means.t1[nro], pch=16)
  lines( rep(current.means.t1$a,2), c(current.means.t1[nro], curves[avg.curve.index,current.means.t1$a]), lwd=1.5, lty=2, col=2)

  # Prepare the closest template such that it will be visible only from the current time point onwards: mark the values of earlier years as NAs
  range.cur <- 1:(current.means.t1$a-1)
  c <- curves[closest.curve.index,]
  c[range.cur] <- NA
  # Draw the line. Then do the same for the averaged curve
  lines(c, lwd=1.5, lty=2)
  c <- curves[avg.curve.index,]
  c[range.cur] <- NA
  lines(c,lwd=1.5, col=2)

} # end loop attributes


#
# Figure 2(d-f) using the other template DB;
# the codes are replicated from above
#


load("nini_1000.RData")

# Species index pointing to the following vector of dominant species : "aw" "pl" "sb" "sw"
# For visualizing, I use of constant value of 1 producing the results for AW
sp <- 1

# Loop over the three column indices used to store the attributes height, basal area, and volume (first index is the dominant species)
for (nro in 2:4) {
  # Extract the curves from the data structures; cf. earlier scripts
  closest.curve.index <- as.numeric(inds.sp.t1[sp,nro])
  if (nro < 3) {
    avg.curve.index <- si.sps[sp]
  } else {
    avg.curve.index <- nini.sps[sp]
  }
  candidate.curves <- list( h=sp.h.curves[sp], g=sp.g.curves[sp], v=sp.v.curves[sp] )
  current.means.t1 <- list( a=a[sp], h=h.t1[sp], g=g.t1[sp], v=v.t1[sp] )
  curves <- candidate.curves[nro-1][[1]][1][[1]]

  # Plotting conventions
  maxs <- c(0,40,37,550)
  plot(range(stand.age), c(0,maxs[nro]), type="n", xlab="Age, years", ylab="", cex.lab=1.25, cex.axis=1.25)
  if (nro==2) {
    text(5, 39.75, "(d)", cex=1.5)
    mtext("Height, m", 2, 2.5, cex=0.85)
  } else if (nro==3) {
    text(5, 36.75, "(e)", cex=1.5)
    mtext(expression(paste("Basal area,  ", m^2/ha)), 2, 2.5, cex=0.85)
  } else {
    text(5, 546, "(f)", cex=1.5)
    mtext(expression(paste("Volume,  ", m^3/ha)), 2, 2.5, cex=0.85)
  } 

  # Draw the curve templates
  for (cc in 1:dim(curves)[1]){
    c <- curves[cc,]
    lines(c, col="grey", lwd=0.5)
  }

  # Draw the observation as a point and draw a vertical line from it to the closest template, illustrating the discrepancy from the observed current state to the point from which the growht projection starts
  points(current.means.t1$a, current.means.t1[nro], pch=16)
  lines( rep(current.means.t1$a,2), c(current.means.t1[nro], curves[avg.curve.index,current.means.t1$a]), lwd=1.5, lty=2, col=2)

  # Prepare the closest template such that it will be visible only from the current time point onwards: mark the values of earlier years as NAs
  range.cur <- 1:(current.means.t1$a-1)
  c <- curves[closest.curve.index,]
  c[range.cur] <- NA
  # Draw the line. Then do the same for the averaged curve
  lines(c, lwd=1.5, lty=2)
  c <- curves[avg.curve.index,]
  c[range.cur] <- NA
  lines(c,lwd=1.5, col=2)

} # end loop attributes



dev.off()



